@@ -15,7 +15,7 @@ def sqlite_string(text):
     """Encode python string into sqlite string."""
     return "'{}'".format(text.replace("'", "''"))
 
-def write_text(filename, text):
+def write_lines(filename, text):
     """Write text (iterable) to file."""
     with open(filename, "w") as file:
         for line in text:
@@ -29,7 +29,12 @@ def make_temporary_file(*args, **kwargs):
     os.remove(filename)
 
 def run_command(cmd, **kwargs):
-    """Run command with environment variables in kwargs."""
+    """Run command with environment variables in kwargs.
+
+    Returns stdout and stderr output.
+    """
     env = os.environ.copy()
     env.update(**kwargs)
-    subprocess.run(shlex.split(cmd), env=env)
+    proc = subprocess.run(shlex.split(cmd), env=env, check=True,
+                          capture_output=True)
+    return proc.stdout, proc.stderr
